import time
import json





# mutual recursion

def listParserAndCodeCreator( theList, rootCode = "", collectionOfCodes = list() ):


	if len(theList) == 0:
		return collectionOfCodes, rootCode


	for itemIdx in range(len(theList)):

		codeSoFar = rootCode
		if (not isinstance( theList[ itemIdx ], dict ) ) and (not isinstance( theList[ itemIdx ], list) ):
			codeSoFar = codeSoFar + '[' + str(itemIdx) + ']'
			collectionOfCodes.append( codeSoFar )

		elif isinstance( theList[ itemIdx ], dict ):
			nestedDict = theList[ itemIdx ]
			codeSoFar = codeSoFar + '[' + str(itemIdx) +  ']'
			collectionOfCodes, codeSoFar = jsonParserAndCodeCreator( nestedDict, codeSoFar, collectionOfCodes )

		elif isinstance( theList[itemIdx], list ):
			nestedList = theList[itemIdx]
			codeSoFar = codeSoFar + '[' + str(itemIdx) + ']'
			collectionOfCodes, codeSoFar = listParserAndCodeCreator( nestedList, codeSoFar, collectionOfCodes )			

	return collectionOfCodes, codeSoFar



def jsonParserAndCodeCreator( theDict:dict, rootCode = "", collectionOfCodes = list() ):


	for key in theDict:
	
		codeSoFar = rootCode
		if (not isinstance(theDict[key], dict ) ) and (not isinstance(theDict[key], list) ):
			codeSoFar = codeSoFar + '["' + str(key) +  '"]'
			collectionOfCodes.append( codeSoFar )

		elif isinstance( theDict[key], dict ):
			nestedDict = theDict[key]
			codeSoFar = codeSoFar + '["' + str(key) +  '"]'
			collectionOfCodes, codeSoFar = jsonParserAndCodeCreator( nestedDict, codeSoFar, collectionOfCodes )

		elif isinstance( theDict[key], list ):
			nestedList = theDict[key]
			codeSoFar = codeSoFar + '["' + str(key) + '"]'
			collectionOfCodes, codeSoFar = listParserAndCodeCreator( nestedList, codeSoFar, collectionOfCodes )			


	return collectionOfCodes, codeSoFar












from setuptools import setup

def readme():
    with open('README.md') as f:
        README = f.read()
    return README


setup(
    name="navigate-json",
    version="1.0.2",
    description="A Python package to manage json objects.",
    long_description=readme(),
    long_description_content_type="text/markdown",
    url="https://https://github.com/70Shubham07/json_navigator",
    author="70Shubham07",
    author_email="shubhamkwwr5@gmail.com",
    license="MIT",
    classifiers=[
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.7",
    ],
    packages=["navJson"],
    include_package_data=True
    # install_requires=["requests"]
    # entry_points={
    #     "console_scripts": [
    #         "weather-reporter=weather_reporter.cli:main",
    #     ]
    # },
)